" Vim Keymap file for Croatian characters, classical variant, UTF-8 encoding
" 
" Maintainer:   Paul B. Mahol <onemda@gmail.com>
" Last Changed: 2007 Oct 14

scriptencoding UTF-8

let b:keymap_name = "croatian-UTF-8"
" Uncomment line below if you prefer short name
"let b:keymap_name = "hr-UTF-8"

loadkeymap
z	y
Z	Y
y	z
Y	Z
[	š
{	Š
]	đ
}	Đ
;	č
:	Č
'	ć
"	Ć
\	ž
|	Ž
@	"
^	&
&	/
*	(
(	)
)	=
_	?
+	*
=	+
-	'
æ	[
ç	]
â	{
î	}
<	;
>	:
/	-
?	_
ö	@
ñ	\
÷	|
å	€
¬	<
®	>
±	~
²	ˇ
³	^
´	˘
µ	°
·	`
¹	´
í	§
Û	÷
Ü	¤
Ý	×
§	ß
ì	ł
Ì	Ł
°	˝
`	¸
½	¸
­	¨
